.. sphinx_argparse_cli::
  :module: parser
  :func: make
  :group_sub_title_prefix:


.. sphinx_argparse_cli::
  :module: parser
  :func: make
  :group_title_prefix: myprog
  :group_sub_title_prefix:
